@@ -10,7 +10,6 @@ _SPIRV_OP(InvalidMemoryModel, "Expects 0-3.")
 _SPIRV_OP(InvalidFunctionControlMask, "")
 _SPIRV_OP(InvalidBuiltinSetName, "Expects OpenCL.std.")
 _SPIRV_OP(InvalidFunctionCall, "Unexpected llvm intrinsic:\n")
-_SPIRV_OP(InvalidArraySize, "Array size must be at least 1:")
 _SPIRV_OP(InvalidBitWidth, "Invalid bit width in input:")
 _SPIRV_OP(InvalidModule, "Invalid SPIR-V module:")
 _SPIRV_OP(InvalidLlvmModule, "Invalid LLVM module:")
@@ -29,6 +28,10 @@ _SPIRV_OP(InvalidVersionNumber,
           "Invalid Version Number.")
 _SPIRV_OP(UnspecifiedMemoryModel, "Unspecified Memory Model.")
 _SPIRV_OP(RepeatedMemoryModel, "Expects a single OpMemoryModel instruction.")
+_SPIRV_OP(DeprecatedExtension,
+          "Feature requires the following deprecated SPIR-V extension:\n")
+_SPIRV_OP(InvalidNumberOfOperands,
+          "Number of operands does not match the expected count.")
 
 /* This is the last error code to have a maximum valid value to compare to */
 _SPIRV_OP(InternalMaxErrorCode, "Unknown error code")
